IndexConst

Struct IndexConst 

struct IndexConst<T: ?Sized>(T);
Since Index and IndexMut aren’t callable in const contexts yet, this helper type helps unify arrays and user-defined array-wrapper types into a single type which can be indexed in const contexts. Once const traits are stabilized this type can go away

Tuple Fields

0: T

Implementations

Source

impl<'a, T, const N: usize> IndexConst<&'a [T; N]>

const fn index(self, i: usize) -> &'a T

Source

impl<'a, 'b, T, const N: usize> IndexConst<&'a mut &'b mut [T; N]>

const fn index_mut(self, i: usize) -> &'a mut T

Source

impl<'a> IndexConst<&'a fiat_p521_tight_field_element>

const fn index(self, i: usize) -> &'a u64

Source

impl<'a, 'b> IndexConst<&'a mut &'b mut fiat_p521_tight_field_element>

const fn index_mut(self, i: usize) -> &'a mut u64

Source

impl<'a> IndexConst<&'a fiat_p521_loose_field_element>

const fn index(self, i: usize) -> &'a u64

Source

impl<'a, 'b> IndexConst<&'a mut &'b mut fiat_p521_loose_field_element>

const fn index_mut(self, i: usize) -> &'a mut u64