struct IndexConst<T: ?Sized>(T);Expand description
Since Index and IndexMut aren’t callable in const contexts yet, this helper type helps unify
arrays and user-defined array-wrapper types into a single type which can be indexed in const
contexts. Once const traits are stabilized this type can go away
Tuple Fields
0: TImplementations
Sourceimpl<'a, T, const N: usize> IndexConst<&'a [T; N]>
impl<'a, T, const N: usize> IndexConst<&'a [T; N]>
Sourceimpl<'a, 'b, T, const N: usize> IndexConst<&'a mut &'b mut [T; N]>
impl<'a, 'b, T, const N: usize> IndexConst<&'a mut &'b mut [T; N]>
Sourceimpl<'a> IndexConst<&'a fiat_p521_tight_field_element>
impl<'a> IndexConst<&'a fiat_p521_tight_field_element>
Sourceimpl<'a, 'b> IndexConst<&'a mut &'b mut fiat_p521_tight_field_element>
impl<'a, 'b> IndexConst<&'a mut &'b mut fiat_p521_tight_field_element>
Sourceimpl<'a> IndexConst<&'a fiat_p521_loose_field_element>
impl<'a> IndexConst<&'a fiat_p521_loose_field_element>
Sourceimpl<'a, 'b> IndexConst<&'a mut &'b mut fiat_p521_loose_field_element>
impl<'a, 'b> IndexConst<&'a mut &'b mut fiat_p521_loose_field_element>